@@ -49,7 +49,7 @@ enum class TokenType
 	PLUS,
 	MULTIPLY,
 	DIVIDE,
-	MODULO,
+	PERCENT,
 	BITWISE_XOR,
 	BITWISE_AND,
 	BITWISE_OR,
@@ -106,6 +106,7 @@ enum class TokenType
 	STRING_OFFSET,
 	STRING_COUNT,
 	ID,
+	ID_WILDCARD,
 	INTEGER_FUNCTION,
 	LSQB, // '['
 	RSQB, // ']'
