@@ -153,7 +153,7 @@ void addEnums(py::module& module)
 		.value("Plus", TokenType::PLUS)
 		.value("Multiply", TokenType::MULTIPLY)
 		.value("Divide", TokenType::DIVIDE)
-		.value("Modulo", TokenType::MODULO)
+		.value("Percent", TokenType::PERCENT)
 		.value("BitwiseXor", TokenType::BITWISE_XOR)
 		.value("BitwiseAnd", TokenType::BITWISE_AND)
 		.value("BitwiseOr", TokenType::BITWISE_OR)
@@ -210,6 +210,7 @@ void addEnums(py::module& module)
 		.value("StringOffset", TokenType::STRING_OFFSET)
 		.value("StringCount", TokenType::STRING_COUNT)
 		.value("Id", TokenType::ID)
+		.value("IdWildcard", TokenType::ID_WILDCARD)
 		.value("IntegerFunction", TokenType::INTEGER_FUNCTION)
 		.value("Lsqb", TokenType::LSQB)
 		.value("Rsqb", TokenType::RSQB)
@@ -526,7 +527,8 @@ void addTokenStreamClass(py::module& module)
 		.def_property_readonly("front", &TokenStream::front)
 		.def_property_readonly("back", &TokenStream::back)
 		.def_property_readonly("tokens", &TokenStream::getTokens)
-		.def_property_readonly("tokens_as_text", &TokenStream::getTokensAsText);
+		.def_property_readonly("tokens_as_text", &TokenStream::getTokensAsText)
+		.def("comment_before_token", &TokenStream::commentBeforeToken, py::arg("message"), py::arg("insert_before"), py::arg("multiline") = false, py::arg("indent") = "", py::arg("linebreak") = true);
 }
 
 void addExpressionClasses(py::module& module)
@@ -540,6 +542,12 @@ void addExpressionClasses(py::module& module)
 				[](const Expression* self) {
 					return self->getText();
 				})
+		.def_property_readonly("token_first", [](const Expression& self) {
+				return *self.getFirstTokenIt();
+			})
+		.def_property_readonly("token_last", [](const Expression& self) {
+				return *self.getLastTokenIt();
+			})
 		.def_property_readonly("tokenstream", [](const Expression& self) { return self.getTokenStream();} );
 
 	exprClass<StringExpression>(module, "StringExpression")
@@ -589,6 +597,7 @@ void addExpressionClasses(py::module& module)
 				py::overload_cast<const Expression::Ptr&>(&UnaryOpExpression::setOperand));
 	unaryOpClass<NotExpression>(module, "NotExpression");
 	unaryOpClass<DefinedExpression>(module, "DefinedExpression");
+	unaryOpClass<PercentualExpression>(module, "PercentualExpression");
 	unaryOpClass<UnaryMinusExpression>(module, "UnaryMinusExpression");
 	unaryOpClass<BitwiseNotExpression>(module, "BitwiseNotExpression");
 
@@ -643,7 +652,10 @@ void addExpressionClasses(py::module& module)
 				&ForArrayExpression::getId,
 				py::overload_cast<const std::string&>(&ForArrayExpression::setId));
 	exprClass<ForStringExpression, ForExpression>(module, "ForStringExpression");
-	exprClass<OfExpression, ForExpression>(module, "OfExpression");
+	exprClass<OfExpression, ForExpression>(module, "OfExpression")
+		.def_property("range",
+				&OfExpression::getRangeExpression,
+				py::overload_cast<const Expression::Ptr&>(&OfExpression::setRangeExpression));
 
 	exprClass<IterableExpression>(module, "IterableExpression")
 		.def_property("elements",
@@ -703,6 +715,7 @@ void addExpressionClasses(py::module& module)
 	keywordClass<EntrypointExpression>(module, "EntrypointExpression");
 	keywordClass<AllExpression>(module, "AllExpression");
 	keywordClass<AnyExpression>(module, "AnyExpression");
+	keywordClass<NoneExpression>(module, "NoneExpression");
 	keywordClass<ThemExpression>(module, "ThemExpression");
 
 	exprClass<ParenthesesExpression>(module, "ParenthesesExpression")
@@ -821,11 +834,13 @@ void addBuilderClasses(py::module& module)
 			})
 		.def("__getitem__", &YaraExpressionBuilder::operator[])
 		.def("access", &YaraExpressionBuilder::access)
-		.def("comment", &YaraExpressionBuilder::comment, py::arg("message"), py::arg("multiline") = false, py::arg("indent") = "")
+		.def("comment", &YaraExpressionBuilder::comment, py::arg("message"), py::arg("multiline") = false, py::arg("indent") = "", py::arg("linebreak") = true)
+		.def("comment_behind", &YaraExpressionBuilder::commentBehind, py::arg("message"), py::arg("multiline") = false, py::arg("indent") = "", py::arg("linebreak") = true)
 		.def("contains", &YaraExpressionBuilder::contains)
 		.def("matches", &YaraExpressionBuilder::matches)
 		.def("iequals", &YaraExpressionBuilder::iequals)
 		.def("defined", &YaraExpressionBuilder::defined)
+		.def("percent", &YaraExpressionBuilder::percent)
 		.def("read_int8", &YaraExpressionBuilder::readInt8)
 		.def("read_int16", &YaraExpressionBuilder::readInt16)
 		.def("read_int32", &YaraExpressionBuilder::readInt32)
@@ -874,7 +889,8 @@ void addBuilderClasses(py::module& module)
 			const YaraExpressionBuilder&,
 			const YaraExpressionBuilder&
 		>(&forLoop));
-	module.def("of", &of);
+	module.def("of", py::overload_cast<const YaraExpressionBuilder&, const YaraExpressionBuilder&>(&of));
+	module.def("of", py::overload_cast<const YaraExpressionBuilder&, const YaraExpressionBuilder&, const YaraExpressionBuilder&>(&of));
 
 	module.def("iterable", &iterable);
 
